@@ -1,11 +1,11 @@
 #!/usr/bin/env python
-import os.path, time, os, sys, re, threading, StringIO, pango, string
-import gtk, gobject, gtk.gdk, traceback
+import os.path, os, re, threading, string
+import gtk, gobject, gtk.gdk
 import batchEditor
 import recipeManager
 from exporters.printer import get_print_manager
-import prefs, prefsGui, shopgui, reccard, fnmatch, tempfile
-import exporters, importers
+import prefs, prefsGui, shopgui, reccard
+import exporters
 from exporters.exportManager import get_export_manager
 from importers.importManager import get_import_manager
 import convert, version
@@ -13,12 +13,9 @@ from gtk_extras import fix_action_group_importance
 from gtk_extras import ratingWidget, WidgetSaver, mnemonic_manager
 from gtk_extras import dialog_extras as de
 from gtk_extras import treeview_extras as te
-from ImageExtras import get_pixbuf_from_jpg
-from gdebug import *
-from gglobals import *
+from gdebug import debug
+from gglobals import DEFAULT_HIDDEN_COLUMNS, REC_ATTRS, doc_base, icondir, imagedir, launch_url, uibase
 from recindex import RecIndex
-#import exporters.recipe_emailer as recipe_emailer
-import locale
 from gettext import gettext as _
 from gettext import ngettext
 from timer import show_timer
@@ -26,45 +23,14 @@ from defaults.defaults import lang as defaults
 from defaults.defaults import get_pluralized_form
 import plugin_loader, plugin, plugin_gui
 from threadManager import get_thread_manager, get_thread_manager_gui, SuspendableThread
-from zipfile import BadZipfile
 
 try:
-    import rtf_exporter
+    from exporters import rtf_exporter
     rtf=True
 except ImportError:
     debug('No RTF support',0)
     rtf=False
 
-def check_for_data_to_import (rm):
-    if rm.fetch_len(rm.recipe_table)==0:
-        try:
-            import legacy_db
-        except ImportError:
-            #print "Not trying to update."
-            #print "We had an import error."
-            #import traceback; traceback.print_exc()
-            1
-        else:
-            pd = de.ProgressDialog(label=_('Importing old recipe data'),
-                                   sublabel=_('Importing recipe data from a previous version of Gourmet into new database.'),
-                                   )
-            def set_prog (p,msg=None):
-                p=float(p)
-                pd.set_progress(p,msg)
-                while gtk.events_pending():
-                    gtk.main_iteration()
-            legacy_db.backup_legacy_data(gourmetdir, pd, set_prog)
-            backup_file = os.path.join(gourmetdir,'GOURMET_DATA_DUMP')
-            if os.path.exists(backup_file):
-                import upgradeHandler        
-                pd.show()
-                upgradeHandler.import_backup_file(
-                    rm,backup_file,set_prog
-                    )
-                os.rename(backup_file,backup_file+'.ALREADY_LOADED')
-                pd.hide()
-                pd.destroy()
-
 class GourmetApplication:
     """The main Gourmet Application.
 
@@ -187,7 +153,6 @@ class GourmetApplication:
         we display the traceback to the user so they can send it out for debugging
         (or possibly make sense of it themselves!)."""
         self.rd = recipeManager.default_rec_manager()
-        check_for_data_to_import(self.rd)
         # initiate autosave stuff autosave every 3 minutes
         # (milliseconds * 1000 milliseconds/second * 60
         # seconds/minute)
@@ -371,7 +336,7 @@ class GourmetApplication:
         debug("show_about (self, *args):",5)
         translator=_("translator-credits")
         # translators should translate the string 'translator-credits'
-        # If we're not using a translatino, then this isn't shown
+        # If we're not using a translation, then this isn't shown
         if translator == "translator-credits":
             translator = None
         # Grab CREDITS from our defaults_LANG file too!
@@ -385,17 +350,18 @@ class GourmetApplication:
 
         # load LICENSE text file
         try:
-            h = open(os.path.join(doc_base,'LICENSE'),'r')
-            s = h.readlines()
+            license_text = open(os.path.join(doc_base,'LICENSE'),'r').read()
         except IOError, err:
             print "IO Error %s" % err
         except:
             print "Unexpexted error"
 
-        license = ""
-        for line in s:
-            license += line
-        h.close()
+        paypal_link = """https://www.paypal.com/cgi-bin/webscr?cmd=_donations
+&business=Thomas_Hinkle%40alumni%2ebrown%2eedu
+&lc=US&item_name=Gourmet%20Recipe%20Manager%20Team&no_note=0&currency_code=USD
+&bn=PP%2dDonationsBF%3abtn_donateCC_LG%2egif%3aNonHostedGuest"""
+        gittip_link = "https://www.gittip.com/on/github/thinkle/"
+        flattr_link = "http://flattr.com/profile/Thomas_Hinkle/things"
 
         about = gtk.AboutDialog()
         about.set_artists(version.artists)
@@ -403,7 +369,7 @@ class GourmetApplication:
         about.set_comments(version.description)
         about.set_copyright(version.copyright)
         #about.set_documenters(None)
-        about.set_license(license)
+        about.set_license(license_text)
         about.set_logo(logo)
         about.set_program_name(version.appname)
         about.set_translator_credits(translator)
@@ -411,6 +377,28 @@ class GourmetApplication:
         #about.set_wrap_license(True)
         about.set_website(version.website)
         #about.set_website_label('Gourmet website')
+
+        donation_buttons = gtk.HButtonBox()
+        donation_buttons.set_layout(gtk.BUTTONBOX_SPREAD)
+        donations_label = gtk.Label(_("Please consider making a donation to "
+        "support our continued effort to fix bugs, implement features, "
+        "and help users!"))
+        donations_label.set_line_wrap(True)
+        donations_label.show()
+        paypal_button = gtk.LinkButton(paypal_link, _("Donate via PayPal"))
+        paypal_button.show()
+        flattr_button = gtk.LinkButton(flattr_link, _("Micro-donate via Flattr"))
+        flattr_button.show()
+        gittip_button = gtk.LinkButton(gittip_link, _("Donate weekly via Gittip"))
+        gittip_button.show()
+        donation_buttons.add(paypal_button)
+        donation_buttons.add(gittip_button)
+        donation_buttons.add(flattr_button)
+        donation_buttons.show()
+        content = about.get_content_area()
+        content.add(donations_label)
+        content.add(donation_buttons)
+
         about.run()
         about.destroy()
 
@@ -647,6 +635,10 @@ def set_path_for_menuitem (mi, base='<main>'):
         sm.set_accel_path(path)
         for c in sm.get_children():
             set_path_for_menuitem(c,path)
+
+def launch_webbrowser(dialog, link, user_data):
+    import webbrowser
+    webbrowser.open_new_tab(link)
     
 def startGUI ():
     debug("startGUI ():",4)
@@ -680,6 +672,9 @@ def startGUI ():
     del pixmap
     splash.show()
     splash.window.set_cursor(gtk.gdk.Cursor(gtk.gdk.WATCH))
+    if os.name == 'nt':
+        gtk.link_button_set_uri_hook(launch_webbrowser, None)
+        gtk.about_dialog_set_url_hook(launch_webbrowser, None)
     #gtk.threads_enter()
     while gtk.events_pending():
         # show our GUI
@@ -784,7 +779,7 @@ class StuffThatShouldBePlugins:
         if self.batchEditor.values:
             changes = self.batchEditor.values
             only_where_blank = self.batchEditor.setFieldWhereBlank
-            attributes = ', '.join(changes.keys())
+            attributes = ', '.join([_(k) for k in changes.keys()])
             msg = ngettext('Set %(attributes)s for %(num)s selected recipe?',
                                    'Set %(attributes)s for %(num)s selected recipes?',
                                    len(recs))%{'attributes':attributes,
@@ -799,15 +794,21 @@ class StuffThatShouldBePlugins:
             if de.getBoolean(label=_('Set values for selected recipes'),sublabel=msg,cancel=False,
                              custom_yes=gtk.STOCK_OK,custom_no=gtk.STOCK_CANCEL,):
                 for r in recs:
+                    # Need to copy in case we're dealing with
+                    # categories as they would get messed up by
+                    # modify_rec
+                    changes = self.batchEditor.values.copy()
                     if only_where_blank:
-                        changes = self.batchEditor.values.copy()
                         for attribute in changes.keys():
-                            if hasattr(r,attribute) and getattr(r,attribute):
+                            if (attribute == 'category' and \
+                                self.rd.get_cats(r)) or \
+                                (hasattr(r, attribute) and \
+                                getattr(r, attribute)):
                                 del changes[attribute]
                         if changes:
                             self.rd.modify_rec(r,changes)
                     else:
-                        self.rd.modify_rec(r,self.batchEditor.values)
+                        self.rd.modify_rec(r,changes)
                     self.rmodel.update_recipe(r)
             else:
                 print 'Cancelled'
