@@ -6,15 +6,15 @@ from gtk_extras import dialog_extras as de
 from gtk_extras import treeview_extras as te
 from gtk_extras import fix_action_group_importance
 from exporters.printer import get_print_manager
-from gdebug import *
-from gglobals import *
+from gdebug import debug
 from gettext import gettext as _
+from gglobals import doc_base
 #from nutrition.nutritionLabel import NutritionLabel
 #from nutrition.nutrition import NutritionInfoList
 import plugin_loader, plugin
 from shopping import ShoppingList
 
-ui = '''
+ui_string = '''
 <ui>
   <menubar name="ShoppingListMenuBar">
     <menu name="File" action="File">
@@ -111,7 +111,7 @@ class IngredientAndPantryList:
 
     def setup_ui_manager (self):
 	self.ui_manager = gtk.UIManager()
-	self.ui_manager.add_ui_from_string(ui)
+	self.ui_manager.add_ui_from_string(ui_string)
 
     def setup_actions (self):
 	self.pantryActions = gtk.ActionGroup('PantryActions')
@@ -574,7 +574,7 @@ class ShopGui (ShoppingList, plugin_loader.Pluggable, IngredientAndPantryList):
     
     def setup_ui_manager (self):
         self.ui_manager = gtk.UIManager()
-        self.ui_manager.add_ui_from_string(ui)
+        self.ui_manager.add_ui_from_string(ui_string)
 
     def setup_main (self):
         mb = self.ui_manager.get_widget('/ShoppingListMenuBar')
@@ -673,7 +673,7 @@ class ShopGui (ShoppingList, plugin_loader.Pluggable, IngredientAndPantryList):
              ),
             ('File',None,_('_File')),
             ('Help',gtk.STOCK_HELP,_('_Help'),None,None,
-             lambda *args: de.show_faq(os.path.join(base,'FAQ'),jump_to='Shopping')),
+             lambda *args: de.show_faq(os.path.join(doc_base,'FAQ'),jump_to='Shopping')),
             ('HelpMenu',None,_('_Help')),
 		])
 	self.mainActionGroup.add_toggle_actions([
